@@ -8,7 +8,6 @@ import numpy as np
 
 from numpy.testing import assert_array_equal, assert_allclose, assert_equal
 
-from mne import io, pick_types
 from mne.fixes import einsum, rfft, irfft
 from mne.utils import requires_sklearn, run_tests_if_main
 from mne.decoding import ReceptiveField, TimeDelayingRidge
@@ -26,11 +25,6 @@ tmin, tmax = -0.1, 0.5
 event_id = dict(aud_l=1, vis_l=3)
 
 # Loading raw data
-raw = io.read_raw_fif(raw_fname, preload=True)
-picks = pick_types(raw.info, meg=True, stim=False, ecg=False,
-                   eog=False, exclude='bads')
-picks = picks[:2]
-
 n_jobs_test = (1, 'cuda')
 
 
